Chat.display_standalone — alfred3_interact

Skip to main content
`Ctrl`+`K`

# Chat.display_standalone

property Chat.display_standalone

  If True (default), the element will be displayed as usual on its own. If False, the element will not be displayed unless you incorporate its `Element.web_widget` in some other way.

  Notes

  An element with `display_standalone = False` will still be validated.

  See also

  Similar to `Element.should_be_shown`. The main difference is that an element with `display_standalone = False` will still be validated, while an element with `should_be_shown = False` will never be validated.

  Type

    bool